<?php

namespace Drupal\group_permission_set\Plugin\Field\FieldWidget;

use Drupal\Core\Entity\FieldableEntityInterface;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\Plugin\Field\FieldWidget\OptionsSelectWidget;

/**
 * Provides a select list that only makes available the sets for the group type.
 *
 * The convention is that the ID of the permission set must start with the ID of
 * the group type. For example, if the group type is called `products`, then the
 * permission sets for it must be called `products_default`,
 * `products_restrictive` etc.
 *
 * @FieldWidget(
 *   id = "group_permission_set_options_select",
 *   label = @Translation("Group permission set select list"),
 *   field_types = {
 *     "entity_reference"
 *   },
 *   multiple_values = TRUE
 * )
 */
class OptionsSelect extends OptionsSelectWidget {

  /**
   * {@inheritdoc}
   */
  protected function getOptions(FieldableEntityInterface $group) {
    $options = parent::getOptions($group);
    $prefix = $group->bundle() . '_';

    $this->options = array_filter(
      $options,
      function ($value, $key) use ($prefix) {
        return str_starts_with($key, $prefix);
      },
      ARRAY_FILTER_USE_BOTH,
    );

    return $this->options;
  }

  /**
   * {@inheritdoc}
   */
  public static function isApplicable(
    FieldDefinitionInterface $field_definition,
  ) {
    return $field_definition->getTargetEntityTypeId() === 'group';
  }

}
